<?php
	//Chris McCue
	//apptadd.php checks for invalid input and then adds appointments to the database and appointments list
	//Modification History:
	//Revision 1:  11/24/2014
	
    include 'medicine-includes.php';

    /*****************************************************************
    ******************************************************************
    **@errorInvalidDate()
    **
    **@brief performs error checking on empty name and invalid dates
    **
    **@return $errorTally (0 for no errors; >0 for errors)
    **
    ******************************************************************
    *****************************************************************/
    function errorInvalidDate(){
    
        $errorTally = 0;
        
        //set variables with form data
        $errorY = $_POST['apptStartYearToForm'];
        $errorM = $_POST['apptStartMonthToForm'];
        $errorD = $_POST['apptStartDayToForm'];

		//invalid input:  entering 31 days for a month with only 30 days
        if(($errorD > 30) && (($errorM == 4) || ($errorM == 6) || ($errorM == 9) || ($errorM == 11))){
            
			//0 for fail; no string to add to appointments list; invalid input message
            $apptRetStatus = '0';
            $updateApptStr = "";
            $messageStr = 'Please enter a valid date. This month only has 30 days.';
            $returnArr = array('successApptStatus' => $apptRetStatus, 'updateApptList' =>$updateApptStr, 'apptReturnMessage' => $messageStr);
            echo json_encode($returnArr); 

            $errorTally++;
        }
		
		//invalid input:  entering more than 29 days for February
        else if(($errorM == 2) && ($errorD > 29)){

			//0 for fail; no string to add to appointments list; invalid input message		
            $apptRetStatus = '0';
            $updateApptStr = "";
            $messageStr = 'Please enter a valid date.<br>February only has 28-29 days.';
            $returnArr = array('successApptStatus' => $apptRetStatus, 'updateApptList' =>$updateApptStr, 'apptReturnMessage' => $messageStr);
            echo json_encode($returnArr); 
            
            $errorTally++;       
        }

		//invalid input:  entering 29 days for February for a non-leap year
        else if(($errorM == 2) && ($errorY % 4 != 0) && ($errorD == 29)){
			
			//0 for fail; no string to add to appointments list; invalid input message
            $apptRetStatus = '0';
            $updateApptStr = "";
            $messageStr = 'Please enter a valid date. Non-leap years only have 28 days.';
            $returnArr = array('successApptStatus' => $apptRetStatus, 'updateApptList' =>$updateApptStr, 'apptReturnMessage' => $messageStr);
            echo json_encode($returnArr); 
            
            $errorTally++;
        }
        return $errorTally;
    }

    /*****************************************************************
    ******************************************************************
    **@generateApptEvents()
    **
    **@brief generates and adds appointments to the database.
    **
    **@params
    **  $username- doctor name
    **  $apptStartDate- date of appointment
    **  $apptStartTime- time of appointment
    **
    ******************************************************************
    *****************************************************************/
    function generateApptEvents($patientSel, $username, $apptStartDate, $apptStartTime){

        $apptStartDateFormatted = date_format($apptStartDate,"m:d:Y");
        $apptStartTimeFormatted = date_format($apptStartTime,"H:i");
        addAppointment($patientSel, $username, $apptStartDateFormatted, $apptStartTimeFormatted);                       
    }

    /*****************************************************************
    ******************************************************************
    **@calculateApptStartTime()
    **
    **@brief converts form data into time object.
    **
    **@return apptStartTime, a time object in military time
    **
    ******************************************************************
    *****************************************************************/
    function calculateApptStartTime(){
    
		//get form data and convert to date object
        $apptStartTimeString = $_POST['apptStartTimeToForm'];  //FORM, like '8:30'
        $apptStartTimeSign = $_POST['apptStartSignToForm'];  //FORM, 'a.m.'
        $apptStartTime = date_create($apptStartTimeString);

        //adjust to military time
		if((($apptStartTimeString == '12:00') || ($apptStartTimeString == '12:30')) && ($apptStartTimeSign == 'a.m.')){
		    date_sub($apptStartTime,date_interval_create_from_date_string("12 hours"));        
		}

		else if((($apptStartTimeString == '12:00') || ($apptStartTimeString == '12:30')) && ($apptStartTimeSign == 'p.m.')){
		    //do nothing        
		}
	
        else if($apptStartTimeSign == 'p.m.'){
            date_add($apptStartTime,date_interval_create_from_date_string("12 hours"));
        }
    
        return $apptStartTime;
    }

    /*****************************************************************
    ******************************************************************
    **@calculateApptStartDate()
    **
    **@brief converts form data into date object.
    **
    **@return apptStartTime, a date object
    **
    ******************************************************************
    *****************************************************************/
    function calculateApptStartDate(){

		//get form date data and convert to date object
        //below from FORM, such as '2014-9-15'      
        $apptStartDateString = $_POST['apptStartYearToForm'].'-'.$_POST['apptStartMonthToForm'].'-'.$_POST['apptStartDayToForm'];
        $apptStartDate = date_create($apptStartDateString);

        return $apptStartDate;
    }

    /******************************************************************
	**************************MAIN CODE********************************
	******************************************************************/
	session_start();    
	$username = $_SESSION['user'];
    $patientSel = $_POST['patientToForm'];  	

    //if no invalid input, continue execution
    if(errorInvalidDate() == 0){

        $apptStartDate = calculateApptStartDate();
        $apptStartTime = calculateApptStartTime();     
        generateApptEvents($patientSel, $username, $apptStartDate, $apptStartTime); 
        
		//1 for success, string to update appointment list item, success status message
		$apptRetStatus = '1';
        $updateApptStr = date_format($apptStartDate,"m:d:Y").'-'.date_format($apptStartTime,"H:i");
        $messageStr = 'Appointment on '.date_format($apptStartDate,"m:d:Y").' at '.date_format($apptStartTime,"H:i").' has been successfully added.';
        $returnArr = array('successApptStatus' => $apptRetStatus, 'updateApptList' =>$updateApptStr, 'apptReturnMessage' => $messageStr);
        echo json_encode($returnArr); 
    }
?>



